import unittest
import os
import spacy
from urllib.request import urlopen

class CompVisTestCase(unittest.TestCase):
    
    def test_model_presence(self):
        model_path = 'keras_model.h5'
        self.assertIn(model_path, os.listdir('.'), 'There is no keras_model.h5 file in your project folder')
    
    def test_presence_readme(self):
        self.assertIn('README.md', os.listdir('.'), 'You should have a README.md file in your project folder')
        with open('README.md', 'r') as f:
            readme = f.read()
        self.assertGreater(len(readme), 500, 'The README.md file should be at least 500 characters long')
        nlp = spacy.load("en_core_web_md")
        documentation = urlopen("https://aicore-files.s3.amazonaws.com/documentation.md")
        tdata = str(documentation.read(), 'utf-8')
        doc_1 = nlp(readme)
        doc_2 = nlp(tdata)
        self.assertLessEqual(doc_1.similarity(doc_2), 0.975, 'The README.md file is almost identical to the one provided in the template')


if __name__ == '__main__':

    unittest.main(verbosity=2)
    


from .verify import get_errors_fails, mark_incomplete, mark_complete
import os

task1_id = '08c1b5f5-7beb-4cec-8189-0f1acc7ca745' # Create an image project model with four different classes: Rock, Paper, Scissors, Nothing
task2_id = 'bcf3c4f1-1547-4727-8e25-a14165eac6d6' # Download the model
task3_id = 'e82a250f-536f-4649-b3e2-2e8680a9119d' # Begin documenting your experience
# test_model_presence
# test_readme_presence

if 'milesone_1.txt' in os.listdir('.'):
    errors = get_errors_fails('milestone_1.txt')


    # If there are no errors, mark everything as complete
    if len(errors) == 0:
        mark_complete(task1_id)
        mark_complete(task2_id)
        mark_complete(task3_id)
    # Check if hangman_solution.py is in the repo
    elif 'test_model_presence' in errors:
        # mark_incomplete(task2_id, message='There is no hangman_solution.py file inside the hangman folder')
        mark_incomplete(task1_id)
        mark_incomplete(task2_id)
        print(errors['test_model_presence'])
    # Check if they are identical
    elif 'test_readme_presence' in errors:
        mark_incomplete(task3_id)
        print(errors['test_readme_presence'])

else:
    mark_incomplete(task1_id)
    mark_incomplete(task2_id)
    mark_incomplete(task3_id)
    print('milestone_1.txt is not in the directory')


from .verify import get_errors_fails, mark_incomplete, mark_complete
import os

task1_id = '2ca4b14e-76dc-44a3-bfcd-052cf78615ef' # Store the user's and the computer's choices
task2_id = 'ae562b8c-bb0f-4861-a9d3-f8695953918b' # Figure out who won
task3_id = 'c1dfcdc5-97a4-4780-ab07-a0c4b785fcd2' # Create a function to simulate the game
task4_id = 'bd6076ef-ac2e-45a1-b38c-b5b1d733f63c' # Update your documentation

# def test_computer_choice_presence
# def test_user_choice_presence
# def test_user_choice_input

# def test_get_winner_presence
# def test_get_winner_args
# def test_get_winner_logic

# def test_play_presence
# def test_play_logic

if 'milesone_3_p2.txt' in os.listdir('.'):
    errors = get_errors_fails('milesone_3_p2.txt')


    # If there are no errors, mark everything as complete
    if len(errors) == 0:
        mark_complete(task1_id)
        mark_complete(task2_id)
        mark_complete(task3_id)

    if ('test_computer_choice_presence' in errors) or ('test_user_choice_presence' in errors) or ('test_user_choice_input' in errors):
        # mark_incomplete(task2_id, message=errors['test_model_presence'])
        mark_incomplete(task1_id)
        mark_incomplete(task2_id)
        mark_incomplete(task3_id)
        if 'test_computer_choice_presence' in errors:
            print(errors['test_computer_choice_presence'])
        if 'test_user_choice_presence' in errors:
            print(errors['test_user_choice_presence'])
        if 'test_user_choice_input' in errors:
            print(errors['test_user_choice_input'])
    
    else:
        mark_complete(task1_id)

    if ('test_get_winner_presence' in errors) or ('test_get_winner_args' in errors) or ('test_get_winner_logic' in errors):
        mark_incomplete(task2_id)
        mark_incomplete(task3_id)
        if 'test_get_winner_presence' in errors:
            print(errors['test_get_winner_presence'])
        if 'test_get_winner_args' in errors:
            print(errors['test_get_winner_args'])
        if 'test_get_winner_logic' in errors:
            print(errors['test_get_winner_logic'])

    else:
        mark_complete(task2_id)

    if ('test_play_presence' in errors) or ('test_play_logic' in errors):
        mark_incomplete(task3_id)
        if 'test_play_presence' in errors:
            print(errors['test_play_presence'])
        if 'test_play_logic' in errors:
            print(errors['test_play_logic'])

    else:
        mark_complete(task3_id)

else:
    mark_incomplete(task1_id)
    mark_incomplete(task2_id)
    mark_incomplete(task3_id)



from .verify import get_errors_fails, mark_incomplete, mark_complete
import os

task1_id = '1ef920ef-7e5f-4078-9e28-eb8e08946319' # Create a new virtual environment
task2_id = 'bbbdf8bf-d35b-4473-857f-dc81d16edac4' # Run the model in your local machine
task3_id = 'c41ad504-5f65-4348-9f4c-5cf9b752e477' # Get familiar with the code

# test_requirements_presence
# test_can_import_opencv
# test_can_import_numpy
# test_can_import_keras

if 'milesone_2.txt' in os.listdir('.'):
    errors = get_errors_fails('milestone_2.txt')

    # If there are no errors, mark everything as complete
    if len(errors) == 0:
        mark_complete(task1_id)
        mark_complete(task2_id)
    # Check if keras_model.h5 is in the repo
    if 'test_requirements_presence' in errors:
        # mark_incomplete(task2_id, message=errors['test_model_presence'])
        mark_incomplete(task1_id)
        print(errors['test_requirements_presence'])
    else:
        mark_complete(task1_id)

        
    if 'test_can_import_numpy' in errors:
        mark_incomplete(task2_id)
        print(errors['test_can_import_numpy'])
    
    elif 'test_can_import_opencv' in errors:
        mark_incomplete(task2_id)
        print(errors['test_can_import_opencv'])

    elif 'test_can_import_keras' in errors:
        mark_incomplete(task2_id)
        print(errors['test_can_import_keras'])
    
    else:
        mark_complete(task2_id)

else:
    mark_incomplete(task1_id)
    mark_incomplete(task2_id)

## TODO: Add verification to tick off task 3 in case the user has gone through the following lessons:

# cbd4ec1b-8781-4dcd-9278-ca75febc2974 Python Environment
# 25d1757b-66ee-4c5d-8489-adcc923fec0e Arithmetic Operations
# 96a873c0-3f66-455d-b672-41c29ca73f0d Lists and sets
# 6556d991-bdd0-4e97-bfb1-c9355f34a868 Dictionaries, tuples and operators
# 34f017d8-c4c0-468c-bd43-bb2f1ed17683 Control Flow



import unittest
import os
import importlib.util


class CompVisTestCase(unittest.TestCase):
    
    def test_requirements_presence(self):
        model_path = 'requirements.txt'
        self.assertIn(model_path, os.listdir('.'), 'There is no requirements.txt file in your project folder')
        with open('requirements.txt') as f:
            requirements = f.read().splitlines()
        libraries = [r.split()[0] for r in requirements[2:]]
        self.assertIn('ipykernel', libraries, 'You should have ipykernel in your requirements.txt file')
        self.assertIn('ipython', libraries, 'You should have ipython in your requirements.txt file')
        self.assertGreater(len(requirements), 10, 'You should have at least 10 lines in your requirements.txt file')

    def test_can_import_opencv(self):
        cv_package = importlib.util.find_spec('cv2')
        self.assertIsNotNone(cv_package, 'You should have OpenCV in your requirements.txt file. If it is not installed, you can install it with pip install opencv-python')

    def test_can_import_numpy(self):
        np_package = importlib.util.find_spec('numpy')
        self.assertIsNotNone(np_package, 'You should have numpy in your requirements.txt file. It is installed when you install tensorflow, so make sure you have tensorflow installed as well')

    def test_can_import_keras(self):
        keras_package = importlib.util.find_spec('keras')
        self.assertIsNotNone(keras_package, 'You should have keras in your requirements.txt file. It is installed when you install tensorflow, so make sure you have tensorflow installed as well')
    
if __name__ == '__main__':

    unittest.main(verbosity=2)
    


from .verify import get_errors_fails, mark_incomplete, mark_complete
import os

task1_id = '2ca4b14e-76dc-44a3-bfcd-052cf78615ef' # Store the user's and the computer's choices
task2_id = 'ae562b8c-bb0f-4861-a9d3-f8695953918b' # Figure out who won
task3_id = 'c1dfcdc5-97a4-4780-ab07-a0c4b785fcd2' # Create a function to simulate the game
task4_id = 'bd6076ef-ac2e-45a1-b38c-b5b1d733f63c' # Update your documentation

# def test_manual_rps_presence
# def test_presence_readme

if 'milesone_3_p1.txt' in os.listdir('.'):
    errors = get_errors_fails('milesone_3_p1.txt')


    # If there are no errors, mark everything as complete
    if 'test_presence_readme' in errors:
        mark_incomplete(task4_id)
        print(errors['test_presence_readme'])
    else:
        mark_complete(task4_id)
    # Check if keras_model.h5 is in the repo
    if 'test_manual_rps_presence' in errors:
        # mark_incomplete(task2_id, message=errors['test_model_presence'])
        mark_incomplete(task1_id)
        mark_incomplete(task2_id)
        print(errors['test_model_presence'])
    # Check if there is a README.md file
    if 'test_presence_readme' in errors:
        mark_incomplete(task3_id)
        print(errors['test_presence_readme'])

else:
    mark_incomplete(task1_id)
    mark_incomplete(task2_id)
    mark_incomplete(task3_id)
    mark_incomplete(task4_id)



import unittest
import os
import manual_rps
from inspect import getsource

class CompVisTestCase(unittest.TestCase):
    
    def test_computer_choice_presence(self):
        self.assertIn("get_computer_choice", manual_rps.__dict__, "You should have a function called get_computer_choice in your manual_rps.py file")
    
    def test_user_choice_presence(self):
        self.assertIn("get_user_choice", manual_rps.__dict__, "You should have a function called get_user_choice in your manual_rps.py file")

    def test_user_choice_input(self):
        self.assertIn("input", getsource(manual_rps.get_user_choice), "The function get_user_choice is not asking for user input")
    
    def test_get_winner_presence(self):
        self.assertIn("get_winner", manual_rps.__dict__, "You should have a function called get_winner in your manual_rps.py file")

    def test_get_winner_args(self):
        args = getsource(manual_rps.get_winner).split('get_winner(')[1].split(')')[0].split(',')
        self.assertEqual(len(args), 2, "The function get_winner should take exactly two arguments: computer_choice and user_choice")
    
    def test_get_winner_logic(self):
        func = getsource(manual_rps.get_winner)
        self.assertIn("if", func, "The function get_winner should have some logic in it, I can't see any if statements")
        self.assertIn("elif", func, "The function get_winner should have some logic in it, I can't see any elif statements")
        self.assertIn("else", func, "The function get_winner should have some logic in it, I can't see any else statements. Even though it's not strictly necessary, implement it on your code")
    
    def test_play_presence(self):
        self.assertIn("play", manual_rps.__dict__, "You should have a function called play in your manual_rps.py file")

    def test_play_logic(self):
        func = getsource(manual_rps.play)
        self.assertIn("get_computer_choice", func, "The function play should call get_computer_choice")
        self.assertIn("get_user_choice", func, "The function play should call get_user_choice")
        self.assertIn("get_winner", func, "The function play should call get_winner")

    


if __name__ == '__main__':

    unittest.main(verbosity=2)
    


import unittest
import os
import spacy
import pkgutil

class CompVisTestCase(unittest.TestCase):
    
    def test_manual_rps_presence(self):
        manual_game_script = 'manual_rps.py'
        self.assertIn(manual_game_script, os.listdir('.'), 'There is no manual_rps.py file in your project folder. If it is there, make sure it is named correctly, and that it is in the main folder')

    def test_presence_readme(self):
        self.assertIn('README.md', os.listdir('.'), 'You should have a README.md file in your project folder')
        with open('README.md', 'r') as f:
            readme = f.read()
        self.assertGreater(len(readme), 1500, 'The README.md file should be at least 1500 characters long')
        nlp = spacy.load("en_core_web_md")
        tdata = str(pkgutil.get_data(__name__, "documentation.md"))
        doc_1 = nlp(readme)
        doc_2 = nlp(tdata)
        self.assertLessEqual(doc_1.similarity(doc_2), 0.975, 'The README.md file is almost identical to the one provided in the template')


if __name__ == '__main__':

    unittest.main(verbosity=2)
    